### Name: calculate.NGSk
### Title: Calculate NGSk (NTk-like) statistics with gene label permutation
### Aliases: calculate.NGSk
### Keywords: array htest

### ** Examples

## Load in expression data and select the probe sets have expression
## values greater than the trimmed mean in at least 1 out of 49 arrays
data(MuscleData)
sf <- apply(MuscleData, 2, mean, tr = 0.025)
temp <- sweep(MuscleData, 2, sf, FUN = '/')
ind.pskeep <- which(rowSums(temp > 1) > 0)
tabMD <- MuscleData[ind.pskeep, ]
probeID <- rownames(tabMD)

rm(temp)

## Select the data to study: IBM vs. NORM _or_ DM vs. NORM
compIBM <- TRUE

if( compIBM == TRUE )  {
  tab <- tabMD[,c(index.NORM, index.IBM)]
  phenotype <- c(rep.int(0,length(index.NORM)), rep.int(1,length(index.IBM)))
}else  {
  tab <- tabMD[,c(index.NORM, index.DM)]
  phenotype <- c(rep.int(0,length(index.NORM)), rep.int(1,length(index.DM)))
}

## Prepare the pathways to analyze
data(GenesetsU133a)
gsList <- selectGeneSets(G, probeID, 20, 500)

nsim <- 1000
ngroups <- 2
verbose <- TRUE
weightType <- "constant"
methodNames <- c("NTk", "NEk")
npath = 25
allpathways <- FALSE

statV <- calcTStatFast(tab, phenotype, ngroups)$tstat
res.NGSk <- calculate.NGSk(statV, gsList, nsim, verbose)
res.NEk <- calculate.NEk(tab, phenotype, gsList, nsim, weightType,
                         ngroups, verbose)

## Summarize top pathways from NGSk
res.pathways.NGSk <-
  rankPathways.NGSk(res.NGSk, G, gsList, methodName = "NGSk",
                    npath)
print(res.pathways.NGSk)

res.pathways <-
  rankPathways(res.NGSk, res.NEk, G, tab, phenotype,
               gsList, ngroups, methodNames, npath, allpathways)
print(res.pathways)

## Get more information about the probe sets' means and other statistics
## for the top pathway in res.pathways
topIndex <- res.pathways$IndexG[1]

res.topPathway.NGSk <-
  getPathwayStatistics.NGSk(statV, probeID, G, topIndex, FALSE, NULL)
print(res.topPathway.NGSk[[1]])

res.topPathway <- getPathwayStatistics(tab, phenotype, G, topIndex,
                                       ngroups, NULL, FALSE, NULL)
print(res.topPathway[[1]])




